# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/events.proto',
  package='event',
  syntax='proto3',
  serialized_options=b'\n\032org.opencord.voltha.eventsZ.github.com/opencord/voltha-protos/v5/go/voltha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1avoltha_protos/events.proto\x12\x05\x65vent\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avoltha_protos/common.proto\"\x9e\x01\n\x12\x45ventFilterRuleKey\"\x87\x01\n\x13\x45ventFilterRuleType\x12\x0e\n\nfilter_all\x10\x00\x12\x0c\n\x08\x63\x61tegory\x10\x01\x12\x10\n\x0csub_category\x10\x02\x12\x12\n\x0ekpi_event_type\x10\x03\x12\x15\n\x11\x63onfig_event_type\x10\x04\x12\x15\n\x11\x64\x65vice_event_type\x10\x05\"\\\n\x0f\x45ventFilterRule\x12:\n\x03key\x18\x01 \x01(\x0e\x32-.event.EventFilterRuleKey.EventFilterRuleType\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x0b\x45ventFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x12\n\nevent_type\x18\x04 \x01(\t\x12%\n\x05rules\x18\x05 \x03(\x0b\x32\x16.event.EventFilterRule\"3\n\x0c\x45ventFilters\x12#\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x12.event.EventFilter\";\n\x0f\x43onfigEventType\"(\n\x05Types\x12\x07\n\x03\x61\x64\x64\x10\x00\x12\n\n\x06remove\x10\x01\x12\n\n\x06update\x10\x02\"U\n\x0b\x43onfigEvent\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.event.ConfigEventType.Types\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"*\n\x0cKpiEventType\"\x1a\n\x05Types\x12\t\n\x05slice\x10\x00\x12\x06\n\x02ts\x10\x01\"\xdf\x01\n\x0eMetricMetaData\x12\r\n\x05title\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x01\x12\x19\n\x11logical_device_id\x18\x03 \x01(\t\x12\x11\n\tserial_no\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x05 \x01(\t\x12\x33\n\x07\x63ontext\x18\x06 \x03(\x0b\x32\".event.MetricMetaData.ContextEntry\x12\x0c\n\x04uuid\x18\x07 \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x10MetricValuePairs\x12\x35\n\x07metrics\x18\x01 \x03(\x0b\x32$.event.MetricValuePairs.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xa4\x01\n\x11MetricInformation\x12\'\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.event.MetricMetaData\x12\x36\n\x07metrics\x18\x02 \x03(\x0b\x32%.event.MetricInformation.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xba\x01\n\x08KpiEvent\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.event.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x02\x12/\n\x08prefixes\x18\x03 \x03(\x0b\x32\x1d.event.KpiEvent.PrefixesEntry\x1aH\n\rPrefixesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.event.MetricValuePairs:\x02\x38\x01\"n\n\tKpiEvent2\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.event.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x01\x12,\n\nslice_data\x18\x03 \x03(\x0b\x32\x18.event.MetricInformation\"\xb4\x01\n\x0b\x44\x65viceEvent\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65vice_event_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\x1f.event.DeviceEvent.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n\x08RPCEvent\x12\x0b\n\x03rpc\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x10\n\x08stack_id\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12-\n\x07\x63ontext\x18\x07 \x03(\x0b\x32\x1c.event.RPCEvent.ContextEntry\x12%\n\x06status\x18\x08 \x01(\x0b\x32\x15.common.OperationResp\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\rEventCategory\"e\n\x05Types\x12\x11\n\rCOMMUNICATION\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\r\n\tEQUIPMENT\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0c\n\x08SECURITY\x10\x05\"R\n\x10\x45ventSubCategory\">\n\x05Types\x12\x07\n\x03PON\x10\x00\x12\x07\n\x03OLT\x10\x01\x12\x07\n\x03ONT\x10\x02\x12\x07\n\x03ONU\x10\x03\x12\x07\n\x03NNI\x10\x04\x12\x08\n\x04NONE\x10\x05\"f\n\tEventType\"Y\n\x05Types\x12\x10\n\x0c\x43ONFIG_EVENT\x10\x00\x12\r\n\tKPI_EVENT\x10\x01\x12\x0e\n\nKPI_EVENT2\x10\x02\x12\x10\n\x0c\x44\x45VICE_EVENT\x10\x03\x12\r\n\tRPC_EVENT\x10\x04\"\x98\x02\n\x0b\x45ventHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x1a.event.EventCategory.Types\x12\x33\n\x0csub_category\x18\x03 \x01(\x0e\x32\x1d.event.EventSubCategory.Types\x12$\n\x04type\x18\x04 \x01(\x0e\x32\x16.event.EventType.Types\x12\x14\n\x0ctype_version\x18\x05 \x01(\t\x12-\n\traised_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breported_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x85\x02\n\x05\x45vent\x12\"\n\x06header\x18\x01 \x01(\x0b\x32\x12.event.EventHeader\x12*\n\x0c\x63onfig_event\x18\x02 \x01(\x0b\x32\x12.event.ConfigEventH\x00\x12$\n\tkpi_event\x18\x03 \x01(\x0b\x32\x0f.event.KpiEventH\x00\x12&\n\nkpi_event2\x18\x04 \x01(\x0b\x32\x10.event.KpiEvent2H\x00\x12*\n\x0c\x64\x65vice_event\x18\x05 \x01(\x0b\x32\x12.event.DeviceEventH\x00\x12$\n\trpc_event\x18\x06 \x01(\x0b\x32\x0f.event.RPCEventH\x00\x42\x0c\n\nevent_typeBL\n\x1aorg.opencord.voltha.eventsZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,])



_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE = _descriptor.EnumDescriptor(
  name='EventFilterRuleType',
  full_name='event.EventFilterRuleKey.EventFilterRuleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='filter_all', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='category', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sub_category', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='kpi_event_type', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='config_event_type', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='device_event_type', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=152,
  serialized_end=287,
)
_sym_db.RegisterEnumDescriptor(_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE)

_CONFIGEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='event.ConfigEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='add', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='remove', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='update', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=576,
  serialized_end=616,
)
_sym_db.RegisterEnumDescriptor(_CONFIGEVENTTYPE_TYPES)

_KPIEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='event.KpiEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='slice', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ts', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=747,
)
_sym_db.RegisterEnumDescriptor(_KPIEVENTTYPE_TYPES)

_EVENTCATEGORY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='event.EventCategory.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUIPMENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECURITY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2025,
  serialized_end=2126,
)
_sym_db.RegisterEnumDescriptor(_EVENTCATEGORY_TYPES)

_EVENTSUBCATEGORY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='event.EventSubCategory.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PON', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OLT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NNI', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2148,
  serialized_end=2210,
)
_sym_db.RegisterEnumDescriptor(_EVENTSUBCATEGORY_TYPES)

_EVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='event.EventType.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIG_EVENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_EVENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RPC_EVENT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2225,
  serialized_end=2314,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE_TYPES)


_EVENTFILTERRULEKEY = _descriptor.Descriptor(
  name='EventFilterRuleKey',
  full_name='event.EventFilterRuleKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTFILTERRULEKEY_EVENTFILTERRULETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=287,
)


_EVENTFILTERRULE = _descriptor.Descriptor(
  name='EventFilterRule',
  full_name='event.EventFilterRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.EventFilterRule.key', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.EventFilterRule.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=381,
)


_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='event.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='event.EventFilter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='event.EventFilter.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='event.EventFilter.device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='event.EventFilter.event_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='event.EventFilter.rules', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=502,
)


_EVENTFILTERS = _descriptor.Descriptor(
  name='EventFilters',
  full_name='event.EventFilters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='event.EventFilters.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=555,
)


_CONFIGEVENTTYPE = _descriptor.Descriptor(
  name='ConfigEventType',
  full_name='event.ConfigEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=616,
)


_CONFIGEVENT = _descriptor.Descriptor(
  name='ConfigEvent',
  full_name='event.ConfigEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='event.ConfigEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='event.ConfigEvent.hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='event.ConfigEvent.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=703,
)


_KPIEVENTTYPE = _descriptor.Descriptor(
  name='KpiEventType',
  full_name='event.KpiEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KPIEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=747,
)


_METRICMETADATA_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='event.MetricMetaData.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.MetricMetaData.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.MetricMetaData.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=973,
)

_METRICMETADATA = _descriptor.Descriptor(
  name='MetricMetaData',
  full_name='event.MetricMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='event.MetricMetaData.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='event.MetricMetaData.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_device_id', full_name='event.MetricMetaData.logical_device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_no', full_name='event.MetricMetaData.serial_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='event.MetricMetaData.device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='event.MetricMetaData.context', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='event.MetricMetaData.uuid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICMETADATA_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=973,
)


_METRICVALUEPAIRS_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='event.MetricValuePairs.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.MetricValuePairs.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.MetricValuePairs.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1096,
)

_METRICVALUEPAIRS = _descriptor.Descriptor(
  name='MetricValuePairs',
  full_name='event.MetricValuePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='event.MetricValuePairs.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICVALUEPAIRS_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1096,
)


_METRICINFORMATION_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='event.MetricInformation.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.MetricInformation.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.MetricInformation.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1096,
)

_METRICINFORMATION = _descriptor.Descriptor(
  name='MetricInformation',
  full_name='event.MetricInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='event.MetricInformation.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='event.MetricInformation.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICINFORMATION_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1263,
)


_KPIEVENT_PREFIXESENTRY = _descriptor.Descriptor(
  name='PrefixesEntry',
  full_name='event.KpiEvent.PrefixesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.KpiEvent.PrefixesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.KpiEvent.PrefixesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1452,
)

_KPIEVENT = _descriptor.Descriptor(
  name='KpiEvent',
  full_name='event.KpiEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='event.KpiEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='event.KpiEvent.ts', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefixes', full_name='event.KpiEvent.prefixes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_KPIEVENT_PREFIXESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1452,
)


_KPIEVENT2 = _descriptor.Descriptor(
  name='KpiEvent2',
  full_name='event.KpiEvent2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='event.KpiEvent2.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='event.KpiEvent2.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice_data', full_name='event.KpiEvent2.slice_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1454,
  serialized_end=1564,
)


_DEVICEEVENT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='event.DeviceEvent.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.DeviceEvent.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.DeviceEvent.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=973,
)

_DEVICEEVENT = _descriptor.Descriptor(
  name='DeviceEvent',
  full_name='event.DeviceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='event.DeviceEvent.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_event_name', full_name='event.DeviceEvent.device_event_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='event.DeviceEvent.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='event.DeviceEvent.context', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEEVENT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1747,
)


_RPCEVENT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='event.RPCEvent.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='event.RPCEvent.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.RPCEvent.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=973,
)

_RPCEVENT = _descriptor.Descriptor(
  name='RPCEvent',
  full_name='event.RPCEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpc', full_name='event.RPCEvent.rpc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='event.RPCEvent.operation_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='event.RPCEvent.service', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack_id', full_name='event.RPCEvent.stack_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='event.RPCEvent.resource_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='event.RPCEvent.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='event.RPCEvent.context', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='event.RPCEvent.status', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RPCEVENT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=2006,
)


_EVENTCATEGORY = _descriptor.Descriptor(
  name='EventCategory',
  full_name='event.EventCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTCATEGORY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2126,
)


_EVENTSUBCATEGORY = _descriptor.Descriptor(
  name='EventSubCategory',
  full_name='event.EventSubCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTSUBCATEGORY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2128,
  serialized_end=2210,
)


_EVENTTYPE = _descriptor.Descriptor(
  name='EventType',
  full_name='event.EventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2212,
  serialized_end=2314,
)


_EVENTHEADER = _descriptor.Descriptor(
  name='EventHeader',
  full_name='event.EventHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='event.EventHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='event.EventHeader.category', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_category', full_name='event.EventHeader.sub_category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='event.EventHeader.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_version', full_name='event.EventHeader.type_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raised_ts', full_name='event.EventHeader.raised_ts', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reported_ts', full_name='event.EventHeader.reported_ts', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2317,
  serialized_end=2597,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='event.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='event.Event.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_event', full_name='event.Event.config_event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kpi_event', full_name='event.Event.kpi_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kpi_event2', full_name='event.Event.kpi_event2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_event', full_name='event.Event.device_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rpc_event', full_name='event.Event.rpc_event', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_type', full_name='event.Event.event_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2600,
  serialized_end=2861,
)

_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE.containing_type = _EVENTFILTERRULEKEY
_EVENTFILTERRULE.fields_by_name['key'].enum_type = _EVENTFILTERRULEKEY_EVENTFILTERRULETYPE
_EVENTFILTER.fields_by_name['rules'].message_type = _EVENTFILTERRULE
_EVENTFILTERS.fields_by_name['filters'].message_type = _EVENTFILTER
_CONFIGEVENTTYPE_TYPES.containing_type = _CONFIGEVENTTYPE
_CONFIGEVENT.fields_by_name['type'].enum_type = _CONFIGEVENTTYPE_TYPES
_KPIEVENTTYPE_TYPES.containing_type = _KPIEVENTTYPE
_METRICMETADATA_CONTEXTENTRY.containing_type = _METRICMETADATA
_METRICMETADATA.fields_by_name['context'].message_type = _METRICMETADATA_CONTEXTENTRY
_METRICVALUEPAIRS_METRICSENTRY.containing_type = _METRICVALUEPAIRS
_METRICVALUEPAIRS.fields_by_name['metrics'].message_type = _METRICVALUEPAIRS_METRICSENTRY
_METRICINFORMATION_METRICSENTRY.containing_type = _METRICINFORMATION
_METRICINFORMATION.fields_by_name['metadata'].message_type = _METRICMETADATA
_METRICINFORMATION.fields_by_name['metrics'].message_type = _METRICINFORMATION_METRICSENTRY
_KPIEVENT_PREFIXESENTRY.fields_by_name['value'].message_type = _METRICVALUEPAIRS
_KPIEVENT_PREFIXESENTRY.containing_type = _KPIEVENT
_KPIEVENT.fields_by_name['type'].enum_type = _KPIEVENTTYPE_TYPES
_KPIEVENT.fields_by_name['prefixes'].message_type = _KPIEVENT_PREFIXESENTRY
_KPIEVENT2.fields_by_name['type'].enum_type = _KPIEVENTTYPE_TYPES
_KPIEVENT2.fields_by_name['slice_data'].message_type = _METRICINFORMATION
_DEVICEEVENT_CONTEXTENTRY.containing_type = _DEVICEEVENT
_DEVICEEVENT.fields_by_name['context'].message_type = _DEVICEEVENT_CONTEXTENTRY
_RPCEVENT_CONTEXTENTRY.containing_type = _RPCEVENT
_RPCEVENT.fields_by_name['context'].message_type = _RPCEVENT_CONTEXTENTRY
_RPCEVENT.fields_by_name['status'].message_type = voltha__protos_dot_common__pb2._OPERATIONRESP
_EVENTCATEGORY_TYPES.containing_type = _EVENTCATEGORY
_EVENTSUBCATEGORY_TYPES.containing_type = _EVENTSUBCATEGORY
_EVENTTYPE_TYPES.containing_type = _EVENTTYPE
_EVENTHEADER.fields_by_name['category'].enum_type = _EVENTCATEGORY_TYPES
_EVENTHEADER.fields_by_name['sub_category'].enum_type = _EVENTSUBCATEGORY_TYPES
_EVENTHEADER.fields_by_name['type'].enum_type = _EVENTTYPE_TYPES
_EVENTHEADER.fields_by_name['raised_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTHEADER.fields_by_name['reported_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['header'].message_type = _EVENTHEADER
_EVENT.fields_by_name['config_event'].message_type = _CONFIGEVENT
_EVENT.fields_by_name['kpi_event'].message_type = _KPIEVENT
_EVENT.fields_by_name['kpi_event2'].message_type = _KPIEVENT2
_EVENT.fields_by_name['device_event'].message_type = _DEVICEEVENT
_EVENT.fields_by_name['rpc_event'].message_type = _RPCEVENT
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['config_event'])
_EVENT.fields_by_name['config_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['kpi_event'])
_EVENT.fields_by_name['kpi_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['kpi_event2'])
_EVENT.fields_by_name['kpi_event2'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['device_event'])
_EVENT.fields_by_name['device_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['rpc_event'])
_EVENT.fields_by_name['rpc_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
DESCRIPTOR.message_types_by_name['EventFilterRuleKey'] = _EVENTFILTERRULEKEY
DESCRIPTOR.message_types_by_name['EventFilterRule'] = _EVENTFILTERRULE
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['EventFilters'] = _EVENTFILTERS
DESCRIPTOR.message_types_by_name['ConfigEventType'] = _CONFIGEVENTTYPE
DESCRIPTOR.message_types_by_name['ConfigEvent'] = _CONFIGEVENT
DESCRIPTOR.message_types_by_name['KpiEventType'] = _KPIEVENTTYPE
DESCRIPTOR.message_types_by_name['MetricMetaData'] = _METRICMETADATA
DESCRIPTOR.message_types_by_name['MetricValuePairs'] = _METRICVALUEPAIRS
DESCRIPTOR.message_types_by_name['MetricInformation'] = _METRICINFORMATION
DESCRIPTOR.message_types_by_name['KpiEvent'] = _KPIEVENT
DESCRIPTOR.message_types_by_name['KpiEvent2'] = _KPIEVENT2
DESCRIPTOR.message_types_by_name['DeviceEvent'] = _DEVICEEVENT
DESCRIPTOR.message_types_by_name['RPCEvent'] = _RPCEVENT
DESCRIPTOR.message_types_by_name['EventCategory'] = _EVENTCATEGORY
DESCRIPTOR.message_types_by_name['EventSubCategory'] = _EVENTSUBCATEGORY
DESCRIPTOR.message_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.message_types_by_name['EventHeader'] = _EVENTHEADER
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventFilterRuleKey = _reflection.GeneratedProtocolMessageType('EventFilterRuleKey', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERRULEKEY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventFilterRuleKey)
  })
_sym_db.RegisterMessage(EventFilterRuleKey)

EventFilterRule = _reflection.GeneratedProtocolMessageType('EventFilterRule', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERRULE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventFilterRule)
  })
_sym_db.RegisterMessage(EventFilterRule)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTER,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventFilter)
  })
_sym_db.RegisterMessage(EventFilter)

EventFilters = _reflection.GeneratedProtocolMessageType('EventFilters', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERS,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventFilters)
  })
_sym_db.RegisterMessage(EventFilters)

ConfigEventType = _reflection.GeneratedProtocolMessageType('ConfigEventType', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGEVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.ConfigEventType)
  })
_sym_db.RegisterMessage(ConfigEventType)

ConfigEvent = _reflection.GeneratedProtocolMessageType('ConfigEvent', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.ConfigEvent)
  })
_sym_db.RegisterMessage(ConfigEvent)

KpiEventType = _reflection.GeneratedProtocolMessageType('KpiEventType', (_message.Message,), {
  'DESCRIPTOR' : _KPIEVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.KpiEventType)
  })
_sym_db.RegisterMessage(KpiEventType)

MetricMetaData = _reflection.GeneratedProtocolMessageType('MetricMetaData', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICMETADATA_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.MetricMetaData.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _METRICMETADATA,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.MetricMetaData)
  })
_sym_db.RegisterMessage(MetricMetaData)
_sym_db.RegisterMessage(MetricMetaData.ContextEntry)

MetricValuePairs = _reflection.GeneratedProtocolMessageType('MetricValuePairs', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICVALUEPAIRS_METRICSENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.MetricValuePairs.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICVALUEPAIRS,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.MetricValuePairs)
  })
_sym_db.RegisterMessage(MetricValuePairs)
_sym_db.RegisterMessage(MetricValuePairs.MetricsEntry)

MetricInformation = _reflection.GeneratedProtocolMessageType('MetricInformation', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICINFORMATION_METRICSENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.MetricInformation.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICINFORMATION,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.MetricInformation)
  })
_sym_db.RegisterMessage(MetricInformation)
_sym_db.RegisterMessage(MetricInformation.MetricsEntry)

KpiEvent = _reflection.GeneratedProtocolMessageType('KpiEvent', (_message.Message,), {

  'PrefixesEntry' : _reflection.GeneratedProtocolMessageType('PrefixesEntry', (_message.Message,), {
    'DESCRIPTOR' : _KPIEVENT_PREFIXESENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.KpiEvent.PrefixesEntry)
    })
  ,
  'DESCRIPTOR' : _KPIEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.KpiEvent)
  })
_sym_db.RegisterMessage(KpiEvent)
_sym_db.RegisterMessage(KpiEvent.PrefixesEntry)

KpiEvent2 = _reflection.GeneratedProtocolMessageType('KpiEvent2', (_message.Message,), {
  'DESCRIPTOR' : _KPIEVENT2,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.KpiEvent2)
  })
_sym_db.RegisterMessage(KpiEvent2)

DeviceEvent = _reflection.GeneratedProtocolMessageType('DeviceEvent', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEEVENT_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.DeviceEvent.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _DEVICEEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.DeviceEvent)
  })
_sym_db.RegisterMessage(DeviceEvent)
_sym_db.RegisterMessage(DeviceEvent.ContextEntry)

RPCEvent = _reflection.GeneratedProtocolMessageType('RPCEvent', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCEVENT_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:event.RPCEvent.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _RPCEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.RPCEvent)
  })
_sym_db.RegisterMessage(RPCEvent)
_sym_db.RegisterMessage(RPCEvent.ContextEntry)

EventCategory = _reflection.GeneratedProtocolMessageType('EventCategory', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCATEGORY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventCategory)
  })
_sym_db.RegisterMessage(EventCategory)

EventSubCategory = _reflection.GeneratedProtocolMessageType('EventSubCategory', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBCATEGORY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventSubCategory)
  })
_sym_db.RegisterMessage(EventSubCategory)

EventType = _reflection.GeneratedProtocolMessageType('EventType', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventType)
  })
_sym_db.RegisterMessage(EventType)

EventHeader = _reflection.GeneratedProtocolMessageType('EventHeader', (_message.Message,), {
  'DESCRIPTOR' : _EVENTHEADER,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.EventHeader)
  })
_sym_db.RegisterMessage(EventHeader)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:event.Event)
  })
_sym_db.RegisterMessage(Event)


DESCRIPTOR._options = None
_METRICMETADATA_CONTEXTENTRY._options = None
_METRICVALUEPAIRS_METRICSENTRY._options = None
_METRICINFORMATION_METRICSENTRY._options = None
_KPIEVENT_PREFIXESENTRY._options = None
_DEVICEEVENT_CONTEXTENTRY._options = None
_RPCEVENT_CONTEXTENTRY._options = None
# @@protoc_insertion_point(module_scope)
